summaryrefslogtreecommitdiffstats
path: root/net/nfs.c
diff options
context:
space:
mode:
Diffstat (limited to 'net/nfs.c')
-rw-r--r--net/nfs.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/net/nfs.c b/net/nfs.c
index 33063d7f61..fe0bc70cbe 100644
--- a/net/nfs.c
+++ b/net/nfs.c
@@ -1,5 +1,5 @@
/*
* NFS support driver - based on etherboot and U-BOOT's tftp.c
*
* Masami Komiya <mkomiya@sonare.it> 2004
*
@@ -539,7 +539,7 @@ nfs_read_reply (uchar *pkt, unsigned len)
}
/**************************************************************************
-Interfaces of U-BOOT
+Interfaces of barebox
**************************************************************************/
static void
@@ -1,5 +1,5 @@
/*
- * NFS support driver - based on etherboot and U-BOOT's tftp.c
+ * NFS support driver - based on etherboot and barebox's tftp.c
*
* Masami Komiya <mkomiya@sonare.it> 2004